# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

from . import _utilities
import typing
# Export this package's modules as members:
from .control_tower_aws_account import *
from .provider import *
from ._inputs import *
from . import outputs

# Make subpackages available:
if typing.TYPE_CHECKING:
    import lbrlabs_pulumi_aws_controltower.config as __config
    config = __config
else:
    config = _utilities.lazy_import('lbrlabs_pulumi_aws_controltower.config')

_utilities.register(
    resource_modules="""
[
 {
  "pkg": "awscontroltower",
  "mod": "index/controlTowerAwsAccount",
  "fqn": "lbrlabs_pulumi_aws_controltower",
  "classes": {
   "awscontroltower:index/controlTowerAwsAccount:controlTowerAwsAccount": "ControlTowerAwsAccount"
  }
 }
]
""",
    resource_packages="""
[
 {
  "pkg": "awscontroltower",
  "token": "pulumi:providers:awscontroltower",
  "fqn": "lbrlabs_pulumi_aws_controltower",
  "class": "Provider"
 }
]
"""
)
